function rotateObject(x,y,ang);
% rotateObject 

if nargin<3,  ang = 90;   end
angy0 = -120;           %  Angle of object at beginning of animation

f = figure;
plot(x,y,'-',x,y,'*');
axis('equal');    title('Outline of object in the x-y plane');
fprintf('\nPress return to continue\n');
pause

x = x(:);  y = y(:);   %  make sure vectors are column vectors
z = zeros(size(x));    %  Initially all z coordinates are zero

XR = rotMat(0,-angy0,0)*[x'; y'; z'];         %  Compute 3D starting position
x0 = XR(1,:);  y0 = XR(2,:);  z0 = XR(3,:);

% --- Draw 3D filled image at initial position
f2 = figure;
p = fill3(x0,y0,z0,'b');
xymax = max([x; y]);
axis([-xymax xymax -xymax xymax -xymax xymax]);
xlabel('x');  ylabel('y')

hold on;  view(55,10);
% --- Rotate forward and backward through nswings
da = 3;
nswings = 3;
for swing=1:nswings
  for k=1:da:ang
    XR = rotMat(0,angy0-k,-k/5)*[x0; y0; z0];    %  Get rotation matrix
    xr = XR(1,:);  yr = XR(2,:);  zr = XR(3,:);  %  Apply it
    set(p,'xdata',xr,'ydata',yr,'zdata',zr);     %  Change data in the plot
    pause(0.02)                                  %  Brief pause
  end
  % --- Rotate backward
  for k=(ang-da):-da:1
    XR = rotMat(0,angy0-k,-k/5)*[x0; y0; z0];    %  Get rotation matrix
    xr = XR(1,:);  yr = XR(2,:);  zr = XR(3,:);  %  Apply it
    set(p,'xdata',xr,'ydata',yr,'zdata',zr);     %  Change data in the plot
    pause(0.02)                                  %  Brief pause
  end
end

% ==============================
function R = rotMat(alpha,beta,zeta)
% rotMat  Creates a rotation matrix for vectors in 3D
%
% Synopsis:  R = rotMat(alpha,beta,zeta)
%
% Input:     alpha = angle, in degrees, of rotation about the x-axis
%            beta  = angle, in degrees, of rotation about the y-axis
%            zeta  = angle, in degrees, of rotation about the z-axis
%
%  Output:  R = matrix that applies the three rotations to a column vector

a = alpha*pi/180;  b = beta*pi/180;  z = zeta*pi/180;  % convert to radians

% --- set up rotation matrices
Rx = [  1       0      0    ;  0     cos(a) -sin(a);   0     sin(a)  cos(a) ];
Ry = [ cos(b)   0     sin(b);  0      1       0    ; -sin(b)  0      cos(b) ];
Rz = [ cos(z) -sin(z)  0    ; sin(z) cos(z)   0    ;   0      0       1     ];

R = Rz*Ry*Rx;

